@@ -6,22 +6,30 @@
 ** Please send bug fixes/bug reports to: Peter Eriksson <pen@lysator.liu.se>
 */
 
-#ifdef SEQUENT
+#ifdef sequent
 #  define _PATH_UNIX "/dynix"
 #endif
 
-#if defined(MIPS) || defined(IRIX) || defined(sco)
+#if defined(MIPS) || defined(IRIX) || defined(sco) || defined(_SEQUENT_)
 #  define _PATH_UNIX "/unix"
 #endif
 
 #if defined(hpux) || defined(__hpux)
+#ifdef HPUX_10
+#  define _PATH_UNIX "/stand/vmunix"
+#else
 #  define _PATH_UNIX "/hp-ux"
 #endif
+#endif
+
+#if defined(__H3050R) || defined(__hiux)
+#  define _PATH_UNIX "/HI-UX"
+#endif
 
 #ifdef SOLARIS
 #  define _PATH_UNIX "/dev/ksyms"
 #else
-#  ifdef SVR4
+#  if defined(SVR4) && !defined(_SEQUENT_)
 #    define _PATH_UNIX "/stand/unix"
 #  endif
 #endif
@@ -36,7 +44,9 @@
 #endif
 
 #ifdef _CRAY
+#ifndef _PATH_UNIX
 #  define _PATH_UNIX "/unicos"
+#endif
 #  define _PATH_MEM  "/dev/mem"
 #endif
 
